[![Build package](https://github.com/refgenie/refgenie/workflows/Build%20package/badge.svg)](https://github.com/refgenie/refgenie/actions?query=workflow%3A%22Build+package%22)
[![Test refgenie CLI](https://github.com/refgenie/refgenie/workflows/Test%20refgenie%20CLI/badge.svg)](https://github.com/refgenie/refgenie/actions?query=workflow%3A%22Test+refgenie+CLI%22)
[![install with bioconda](https://img.shields.io/badge/install%20with-bioconda-brightgreen.svg?style=flat)](http://bioconda.github.io/recipes/refgenie/README.html)

<img src="https://raw.githubusercontent.com/databio/refgenie/master/docs/img/refgenie_logo.svg?sanitize=true" alt="Refgenie" height="70"/><br>

A standardized reference genome resource manager. See the [documentation](http://refgenie.databio.org).
